{% extends "core_main_app/_render/admin/theme/tools/section.html" %}

{% block section_title %}Workspaces{% endblock %}

{% block section_content %}
    <div class="row">
        <div class="col-md-12">
            {% include 'core_dashboard_app/admin/my_dashboard_content.html' %}
        </div>
    </div>
{% endblock %}
